package service

import (
	"fmt"
	monitoringv1 "github.com/prometheus-operator/prometheus-operator/pkg/apis/monitoring/v1"
	"github.com/spf13/cast"
	"gitlab.wodcloud.com/smart-operation/so-operation-api/src/bean/entity"
	"gitlab.wodcloud.com/smart-operation/so-operation-api/src/bean/vo/response"
	"gitlab.wodcloud.com/smart-operation/so-operation-api/src/common/conf"
	"gitlab.wodcloud.com/smart-operation/so-operation-api/src/pkg/beagle/constant"
	"gitlab.wodcloud.com/smart-operation/so-operation-api/src/service/k8s"
	"go.uber.org/zap"
	"k8s.io/apimachinery/pkg/util/intstr"
	"log"
	"strings"
)

type PrometheusRuleSvc struct {
	User entity.SystemUserInfo
}

func (p *PrometheusRuleSvc) Create(data response.AlertRulesItem) (err error) {
	pr := monitoringv1.PrometheusRule{}
	prometheusRuleName := k8s.GetPrometheusRuleName(data.Id)
	pr.Name = prometheusRuleName
	pr.Namespace = k8s.Namespace
	pr.Labels = k8s.AlertDefLabels

	group := monitoringv1.RuleGroup{}
	groupInterval := monitoringv1.Duration(fmt.Sprintf("%d%s", data.CheckPeriod, "m"))
	group.Interval = &groupInterval
	ruleFor := monitoringv1.Duration(fmt.Sprintf("%d%s", data.Duration, data.DurationUnit))
	group.Name = k8s.GetPrometheusRuleGroupName(data.MetricConfigId, string(*group.Interval))
	for _, v := range data.AlertRange {
		item := fmt.Sprintf(`%s%s"%s"`, v.MetricLabel, v.Compare, v.Value) // http_requests_total{method="GET",pod="LeaseGrant"}
		data.Expr = strings.ReplaceAll(data.Expr, v.VariableName, item)
	}
	for _, v := range data.AlertCondition {
		rule := monitoringv1.Rule{
			Alert: data.MetricConfigName,
			For:   &ruleFor,
			Labels: map[string]string{
				"severity":        "warning",
				"risk_level":      cast.ToString(v.RiskLevel),
				"risk_level_name": constant.RiskLeveText(v.RiskLevel),
				"source":          "so-operation-api",
				"alert_rules_id":  data.MetricConfigId,
			},
			Annotations: map[string]string{
				"value":       "{{ $value }}",
				"summary":     fmt.Sprintf("分组名:%s, 检查周期:%s, 持续时间:%s", group.Name, string(groupInterval), string(ruleFor)),
				"description": "",
			},
		}
		expr := fmt.Sprintf("%d <= %s <=%d", v.ThresholdsMin, data.Expr, v.ThresholdsMax)
		rule.Expr = intstr.FromString(expr)
		group.Rules = append(group.Rules, rule)
	}
	pr.Spec.Groups = append(pr.Spec.Groups, group)
	header := make(map[string]string)
	header["Authorization"] = "Bearer " + conf.Options.KubernetesToken
	prSvc := k8s.PrometheusRule{Header: header}
	conf.Logger.Info("创建规则", zap.Any("pr", pr))
	err = prSvc.Create(&pr)
	if err != nil {
		log.Println("添加失败" + err.Error())
	} else {
		log.Println("添加成功")
	}
	return
}
